
from .velkoz import(
        get_summoner

        )





from .tentacles import (
        AccountApi,
        ChampionMasteryApi,
        RiotApiService,
        api_key,
        MatchApi,
        SummonerApi
        )

from .eye import (
        Summoner,
        Match,
        Participant,
        Account
        )
